=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2005-11-13 16:46:19 +0000
+++ bzrlib/builtins.py	2005-11-17 08:12:13 +0000
@@ -35,29 +35,23 @@
 from bzrlib.workingtree import WorkingTree
 
 
-def branch_files(file_list, default_branch='.'):
+def tree_files(file_list, default_branch='.'):
     """\
     Return a branch and list of branch-relative paths.
     If supplied file_list is empty or None, the branch default will be used,
     and returned file_list will match the original.
     """
     if file_list is None or len(file_list) == 0:
-        return Branch.open_containing(default_branch)[0], file_list
-    b = Branch.open_containing(file_list[0])[0]
-    
-    # note that if this is a remote branch, we would want
-    # relpath against the transport. RBC 20051018
-    # Most branch ops can't meaningfully operate on files in remote branches;
-    # the above comment was in cmd_status.  ADHB 20051026
-    tree = WorkingTree(b.base, b)
+        return WorkingTree.open_containing(default_branch)[0], file_list
+    tree = WorkingTree.open_containing(file_list[0])[0]
     new_list = []
     for filename in file_list:
         try:
             new_list.append(tree.relpath(filename))
         except NotBranchError:
-            raise BzrCommandError("%s is not in the same branch as %s" % 
+            raise BzrCommandError("%s is not in the same tree as %s" % 
                                   (filename, file_list[0]))
-    return b, new_list
+    return tree, new_list
 
 
 # TODO: Make sure no commands unconditionally use the working directory as a
@@ -117,10 +111,10 @@
     
     @display_command
     def run(self, all=False, show_ids=False, file_list=None, revision=None):
-        b, file_list = branch_files(file_list)
+        tree, file_list = tree_files(file_list)
             
         from bzrlib.status import show_status
-        show_status(b, show_unchanged=all, show_ids=show_ids,
+        show_status(tree.branch, show_unchanged=all, show_ids=show_ids,
                     specific_files=file_list, revision=revision)
 
 
@@ -142,7 +136,7 @@
             raise BzrCommandError('You can only supply one of revision_id or --revision')
         if revision_id is None and revision is None:
             raise BzrCommandError('You must supply either --revision or a revision_id')
-        b = Branch.open_containing('.')[0]
+        b = WorkingTree.open_containing('.')[0].branch
         if revision_id is not None:
             sys.stdout.write(b.get_revision_xml_file(revision_id).read())
         elif revision is not None:
@@ -180,7 +174,7 @@
         if len(revs) == 0:
             raise BzrCommandError('You must supply a revision identifier')
 
-        b = Branch.open_containing('.')[0]
+        b = WorkingTree.open_containing('.')[0].branch
 
         for rev in revs:
             revinfo = rev.in_history(b)
@@ -237,7 +231,8 @@
         
         for d in dir_list:
             os.mkdir(d)
-            b, dd = Branch.open_containing(d)
+            wt, dd = WorkingTree.open_containing(d)
+            b = wt.branch
             b.add([dd])
             print 'added', d
 
@@ -249,7 +244,7 @@
     
     @display_command
     def run(self, filename):
-        branch, relpath = Branch.open_containing(filename)
+        tree, relpath = WorkingTree.open_containing(filename)
         print relpath
 
 
@@ -259,14 +254,15 @@
     
     @display_command
     def run(self, revision=None, show_ids=False):
-        b = Branch.open_containing('.')[0]
+        tree = WorkingTree.open_containing('.')[0]
         if revision is None:
-            inv = b.working_tree().read_working_inventory()
+            inv = tree.read_working_inventory()
         else:
             if len(revision) > 1:
                 raise BzrCommandError('bzr inventory --revision takes'
                     ' exactly one revision identifier')
-            inv = b.get_revision_inventory(revision[0].in_history(b).rev_id)
+            inv = tree.branch.get_revision_inventory(
+                revision[0].in_history(tree.branch).rev_id)
 
         for path, entry in inv.entries():
             if show_ids:
@@ -285,11 +281,10 @@
     """
     takes_args = ['source$', 'dest']
     def run(self, source_list, dest):
-        b, source_list = branch_files(source_list)
+        tree, source_list = tree_files(source_list)
 
         # TODO: glob expansion on windows?
-        tree = WorkingTree(b.base, b)
-        b.move(source_list, tree.relpath(dest))
+        tree.branch.move(source_list, tree.relpath(dest))
 
 
 class cmd_rename(Command):
@@ -309,8 +304,8 @@
     takes_args = ['from_name', 'to_name']
     
     def run(self, from_name, to_name):
-        b, (from_name, to_name) = branch_files((from_name, to_name))
-        b.rename_one(from_name, to_name)
+        tree, (from_name, to_name) = tree_files((from_name, to_name))
+        tree.branch.rename_one(from_name, to_name)
 
 
 class cmd_mv(Command):
@@ -330,17 +325,17 @@
     def run(self, names_list):
         if len(names_list) < 2:
             raise BzrCommandError("missing file argument")
-        b, rel_names = branch_files(names_list)
+        tree, rel_names = tree_files(names_list)
         
         if os.path.isdir(names_list[-1]):
             # move into existing directory
-            for pair in b.move(rel_names[:-1], rel_names[-1]):
+            for pair in tree.branch.move(rel_names[:-1], rel_names[-1]):
                 print "%s => %s" % pair
         else:
             if len(names_list) != 2:
                 raise BzrCommandError('to mv multiple files the destination '
                                       'must be a versioned directory')
-            b.rename_one(rel_names[0], rel_names[1])
+            tree.branch.rename_one(rel_names[0], rel_names[1])
             print "%s => %s" % (rel_names[0], rel_names[1])
             
     
@@ -370,8 +365,8 @@
         from shutil import rmtree
         import errno
         
-        br_to = Branch.open_containing('.')[0]
-        stored_loc = br_to.get_parent()
+        tree_to = WorkingTree.open_containing('.')[0]
+        stored_loc = tree_to.branch.get_parent()
         if location is None:
             if stored_loc is None:
                 raise BzrCommandError("No pull location known or specified.")
@@ -380,20 +375,20 @@
                 location = stored_loc
         br_from = Branch.open(location)
         try:
-            old_rh = br_to.revision_history()
-            br_to.working_tree().pull(br_from, overwrite)
+            old_rh = tree_to.branch.revision_history()
+            tree_to.pull(br_from, overwrite)
         except DivergedBranches:
             raise BzrCommandError("These branches have diverged."
                                   "  Try merge.")
-        if br_to.get_parent() is None or remember:
-            br_to.set_parent(location)
+        if tree_to.branch.get_parent() is None or remember:
+            tree_to.branch.set_parent(location)
 
         if verbose:
-            new_rh = br_to.revision_history()
+            new_rh = tree_to.branch.revision_history()
             if old_rh != new_rh:
                 # Something changed
                 from bzrlib.log import show_changed_revisions
-                show_changed_revisions(br_to, old_rh, new_rh)
+                show_changed_revisions(tree_to.branch, old_rh, new_rh)
 
 
 class cmd_push(Command):
@@ -431,8 +426,8 @@
         from shutil import rmtree
         from bzrlib.transport import get_transport
         
-        br_from = Branch.open_containing('.')[0]
-        stored_loc = br_from.get_push_location()
+        tree_from = WorkingTree.open_containing('.')[0]
+        stored_loc = tree_from.branch.get_push_location()
         if location is None:
             if stored_loc is None:
                 raise BzrCommandError("No push location known or specified.")
@@ -470,12 +465,12 @@
             br_to = Branch.initialize(location)
         try:
             old_rh = br_to.revision_history()
-            br_to.pull(br_from, overwrite)
+            br_to.pull(tree_from.branch, overwrite)
         except DivergedBranches:
             raise BzrCommandError("These branches have diverged."
                                   "  Try a merge then push with overwrite.")
-        if br_from.get_push_location() is None or remember:
-            br_from.set_push_location(location)
+        if tree_from.branch.get_push_location() is None or remember:
+            tree_from.branch.set_push_location(location)
 
         if verbose:
             new_rh = br_to.revision_history()
@@ -484,6 +479,7 @@
                 from bzrlib.log import show_changed_revisions
                 show_changed_revisions(br_to, old_rh, new_rh)
 
+
 class cmd_branch(Command):
     """Create a new copy of a branch.
 
@@ -521,7 +517,7 @@
         br_from.lock_read()
         try:
             if basis is not None:
-                basis_branch = Branch.open_containing(basis)[0]
+                basis_branch = WorkingTree.open_containing(basis)[0].branch
             else:
                 basis_branch = None
             if len(revision) == 1 and revision[0] is not None:
@@ -572,9 +568,9 @@
 
     @display_command
     def run(self, dir='.'):
-        b = Branch.open_containing(dir)[0]
-        old_inv = b.basis_tree().inventory
-        new_inv = b.working_tree().read_working_inventory()
+        tree = WorkingTree.open_containing(dir)[0]
+        old_inv = tree.branch.basis_tree().inventory
+        new_inv = tree.read_working_inventory()
 
         renames = list(bzrlib.tree.find_renames(old_inv, new_inv))
         renames.sort()
@@ -589,7 +585,7 @@
     @display_command
     def run(self, branch=None):
         import info
-        b = Branch.open_containing(branch)[0]
+        b = WorkingTree.open_containing(branch)[0].branch
         info.show_info(b)
 
 
@@ -604,8 +600,7 @@
     aliases = ['rm']
     
     def run(self, file_list, verbose=False):
-        b, file_list = branch_files(file_list)
-        tree = b.working_tree()
+        tree, file_list = tree_files(file_list)
         tree.remove(file_list, verbose=verbose)
 
 
@@ -620,8 +615,8 @@
     takes_args = ['filename']
     @display_command
     def run(self, filename):
-        b, relpath = Branch.open_containing(filename)
-        i = b.inventory.path2id(relpath)
+        tree, relpath = WorkingTree.open_containing(filename)
+        i = tree.inventory.path2id(relpath)
         if i == None:
             raise BzrError("%r is not a versioned file" % filename)
         else:
@@ -637,8 +632,8 @@
     takes_args = ['filename']
     @display_command
     def run(self, filename):
-        b, relpath = Branch.open_containing(filename)
-        inv = b.inventory
+        tree, relpath = WorkingTree.open_containing(filename)
+        inv = tree.inventory
         fid = inv.path2id(relpath)
         if fid == None:
             raise BzrError("%r is not a versioned file" % filename)
@@ -651,7 +646,8 @@
     hidden = True
     @display_command
     def run(self):
-        for patchid in Branch.open_containing('.')[0].revision_history():
+        branch = WorkingTree.open_containing('.')[0].branch
+        for patchid in branch.revision_history():
             print patchid
 
 
@@ -660,16 +656,18 @@
     hidden = True
     @display_command
     def run(self):
-        b = Branch.open_containing('.')[0]
+        tree = WorkingTree.open_containing('.')[0]
+        b = tree.branch
+        # FIXME. should be tree.last_revision
         for revision_id in b.get_ancestry(b.last_revision()):
             print revision_id
 
 
 class cmd_directories(Command):
-    """Display list of versioned directories in this branch."""
+    """Display list of versioned directories in this tree."""
     @display_command
     def run(self):
-        for name, ie in (Branch.open_containing('.')[0].working_tree().
+        for name, ie in (WorkingTree.open_containing('.')[0].
                          read_working_inventory().directories()):
             if name == '':
                 print '.'
@@ -739,19 +737,19 @@
     def run(self, revision=None, file_list=None, diff_options=None):
         from bzrlib.diff import show_diff
         
-        b, file_list = branch_files(file_list)
+        tree, file_list = tree_files(file_list)
         if revision is not None:
             if len(revision) == 1:
-                return show_diff(b, revision[0], specific_files=file_list,
+                return show_diff(tree.branch, revision[0], specific_files=file_list,
                                  external_diff_options=diff_options)
             elif len(revision) == 2:
-                return show_diff(b, revision[0], specific_files=file_list,
+                return show_diff(tree.branch, revision[0], specific_files=file_list,
                                  external_diff_options=diff_options,
                                  revision2=revision[1])
             else:
                 raise BzrCommandError('bzr diff --revision takes exactly one or two revision identifiers')
         else:
-            return show_diff(b, None, specific_files=file_list,
+            return show_diff(tree.branch, None, specific_files=file_list,
                              external_diff_options=diff_options)
 
 
@@ -766,11 +764,10 @@
     # if the directories are very large...)
     @display_command
     def run(self, show_ids=False):
-        b = Branch.open_containing('.')[0]
-        old = b.basis_tree()
-        new = b.working_tree()
+        tree = WorkingTree.open_containing('.')[0]
+        old = tree.branch.basis_tree()
         for path, ie in old.inventory.iter_entries():
-            if not new.has_id(ie.file_id):
+            if not tree.has_id(ie.file_id):
                 if show_ids:
                     print '%-50s %s' % (path, ie.file_id)
                 else:
@@ -784,8 +781,8 @@
     def run(self):
         from bzrlib.delta import compare_trees
 
-        b = Branch.open_containing('.')[0]
-        td = compare_trees(b.basis_tree(), b.working_tree())
+        tree = WorkingTree.open_containing('.')[0]
+        td = compare_trees(tree.branch.basis_tree(), tree)
 
         for path, id, kind, text_modified, meta_modified in td.modified:
             print path
@@ -797,9 +794,8 @@
     hidden = True
     @display_command
     def run(self):
-        b = Branch.open_containing('.')[0]
-        wt = b.working_tree()
-        basis_inv = b.basis_tree().inventory
+        wt = WorkingTree.open_containing('.')[0]
+        basis_inv = wt.branch.basis_tree().inventory
         inv = wt.inventory
         for file_id in inv:
             if file_id in basis_inv:
@@ -820,8 +816,8 @@
     @display_command
     def run(self, filename=None):
         """Print the branch root."""
-        b = Branch.open_containing(filename)[0]
-        print b.base
+        tree = WorkingTree.open_containing(filename)[0]
+        print tree.basedir
 
 
 class cmd_log(Command):
@@ -863,17 +859,26 @@
         direction = (forward and 'forward') or 'reverse'
         
         if filename:
-            b, fp = Branch.open_containing(filename)
+            # might be a tree:
+            tree = None
+            try:
+                tree, fp = WorkingTree.open_containing(filename)
+                b = tree.branch
+                if fp != '':
+                    inv = tree.read_working_inventory()
+            except NotBranchError:
+                pass
+            if tree is None:
+                b, fp = Branch.open_containing(filename)
+                if fp != '':
+                    inv = b.get_inventory(b.last_revision())
             if fp != '':
-                try:
-                    inv = b.working_tree().read_working_inventory()
-                except NoWorkingTree:
-                    inv = b.get_inventory(b.last_revision())
                 file_id = inv.path2id(fp)
             else:
                 file_id = None  # points to branch root
         else:
-            b, relpath = Branch.open_containing('.')
+            tree, relpath = WorkingTree.open_containing('.')
+            b = tree.branch
             file_id = None
 
         if revision is None:
@@ -927,8 +932,9 @@
     takes_args = ["filename"]
     @display_command
     def run(self, filename):
-        b, relpath = Branch.open_containing(filename)[0]
-        inv = b.working_tree().read_working_inventory()
+        tree, relpath = WorkingTree.open_containing(filename)
+        b = tree.branch
+        inv = tree.read_working_inventory()
         file_id = inv.path2id(relpath)
         for revno, revision_id, what in bzrlib.log.find_touching_revisions(b, file_id):
             print "%6d %s" % (revno, what)
@@ -962,15 +968,14 @@
 
         selection = {'I':ignored, '?':unknown, 'V':versioned}
 
-        b, relpath = Branch.open_containing('.')
+        tree, relpath = WorkingTree.open_containing('.')
         if from_root:
             relpath = ''
         elif relpath:
             relpath += '/'
-        if revision == None:
-            tree = b.working_tree()
-        else:
-            tree = b.revision_tree(revision[0].in_history(b).rev_id)
+        if revision is not None:
+            tree = tree.branch.revision_tree(
+                revision[0].in_history(tree.branch).rev_id)
         for fp, fc, kind, fid, entry in tree.list_files():
             if fp.startswith(relpath):
                 fp = fp[len(relpath):]
@@ -989,17 +994,15 @@
                     print fp
 
 
-
 class cmd_unknowns(Command):
     """List unknown files."""
     @display_command
     def run(self):
         from bzrlib.osutils import quotefn
-        for f in Branch.open_containing('.')[0].unknowns():
+        for f in WorkingTree.open_containing('.')[0].branch.unknowns():
             print quotefn(f)
 
 
-
 class cmd_ignore(Command):
     """Ignore a command or pattern.
 
@@ -1025,8 +1028,8 @@
         from bzrlib.atomicfile import AtomicFile
         import os.path
 
-        b, relpath = Branch.open_containing('.')
-        ifn = b.abspath('.bzrignore')
+        tree, relpath = WorkingTree.open_containing('.')
+        ifn = tree.abspath('.bzrignore')
 
         if os.path.exists(ifn):
             f = open(ifn, 'rt')
@@ -1051,13 +1054,12 @@
         finally:
             f.close()
 
-        inv = b.working_tree().inventory
+        inv = tree.inventory
         if inv.path2id('.bzrignore'):
             mutter('.bzrignore is already versioned')
         else:
             mutter('need to make new .bzrignore file versioned')
-            b.add(['.bzrignore'])
-
+            tree.branch.add(['.bzrignore'])
 
 
 class cmd_ignored(Command):
@@ -1066,7 +1068,7 @@
     See also: bzr ignore"""
     @display_command
     def run(self):
-        tree = Branch.open_containing('.')[0].working_tree()
+        tree = WorkingTree.open_containing('.')[0]
         for path, file_class, kind, file_id, entry in tree.list_files():
             if file_class != 'I':
                 continue
@@ -1091,7 +1093,7 @@
         except ValueError:
             raise BzrCommandError("not a valid revision-number: %r" % revno)
 
-        print Branch.open_containing('.')[0].get_rev_id(revno)
+        print WorkingTree.open_containing('.')[0].branch.get_rev_id(revno)
 
 
 class cmd_export(Command):
@@ -1110,9 +1112,11 @@
     takes_options = ['revision', 'format', 'root']
     def run(self, dest, revision=None, format=None, root=None):
         import os.path
-        b = Branch.open_containing('.')[0]
+        tree = WorkingTree.open_containing('.')[0]
+        b = tree.branch
         if revision is None:
-            rev_id = b.last_revision()
+            # should be tree.last_revision  FIXME
+            rev_id = tree.branch.last_revision()
         else:
             if len(revision) != 1:
                 raise BzrError('bzr export --revision takes exactly 1 argument')
@@ -1150,7 +1154,14 @@
             raise BzrCommandError("bzr cat requires a revision number")
         elif len(revision) != 1:
             raise BzrCommandError("bzr cat --revision takes exactly one number")
-        b, relpath = Branch.open_containing(filename)
+        tree = None
+        try:
+            tree, relpath = WorkingTree.open_containing(filename)
+            b = tree.branch
+        except NotBranchError:
+            pass
+        if tree is None:
+            b, relpath = Branch.open_containing(filename)
         b.print_file(relpath, revision[0].in_history(b).revno)
 
 
@@ -1206,10 +1217,10 @@
         from bzrlib.status import show_status
         from cStringIO import StringIO
 
-        b, selected_list = branch_files(selected_list)
+        tree, selected_list = tree_files(selected_list)
         if message is None and not file:
             catcher = StringIO()
-            show_status(b, specific_files=selected_list,
+            show_status(tree.branch, specific_files=selected_list,
                         to_file=catcher)
             message = edit_commit_message(catcher.getvalue())
 
@@ -1227,8 +1238,8 @@
                 raise BzrCommandError("empty commit message specified")
             
         try:
-            b.working_tree().commit(message, specific_files=selected_list,
-                     allow_pointless=unchanged, strict=strict)
+            tree.commit(message, specific_files=selected_list,
+                        allow_pointless=unchanged, strict=strict)
         except PointlessCommit:
             # FIXME: This should really happen before the file is read in;
             # perhaps prepare the commit; get the message; then actually commit
@@ -1253,7 +1264,7 @@
 
     def run(self, dir='.', verbose=False):
         from bzrlib.check import check
-        check(Branch.open_containing(dir)[0], verbose)
+        check(WorkingTree.open_containing(dir)[0].branch, verbose)
 
 
 class cmd_scan_cache(Command):
@@ -1299,7 +1310,7 @@
     @display_command
     def run(self, email=False):
         try:
-            b = bzrlib.branch.Branch.open_containing('.')[0]
+            b = WorkingTree.open_containing('.')[0].branch
             config = bzrlib.config.BranchConfig(b)
         except NotBranchError:
             config = bzrlib.config.GlobalConfig()
@@ -1461,7 +1472,7 @@
         if merge_type is None:
             merge_type = ApplyMerge3
         if branch is None:
-            branch = Branch.open_containing('.')[0].get_parent()
+            branch = WorkingTree.open_containing('.')[0].branch.get_parent()
             if branch is None:
                 raise BzrCommandError("No merge location known or specified.")
             else:
@@ -1524,14 +1535,15 @@
             file_list = []
         if revision is None:
             revno = -1
-            b = Branch.open_containing('.')[0]
-            rev_id = b.last_revision()
+            tree = WorkingTree.open_containing('.')[0]
+            # FIXME should be tree.last_revision
+            rev_id = tree.branch.last_revision()
         elif len(revision) != 1:
             raise BzrCommandError('bzr revert --revision takes exactly 1 argument')
         else:
-            b, file_list = branch_files(file_list)
-            rev_id = revision[0].in_history(b).rev_id
-        b.working_tree().revert(file_list, b.revision_tree(rev_id),
+            tree, file_list = tree_files(file_list)
+            rev_id = revision[0].in_history(tree.branch).rev_id
+        tree.revert(file_list, tree.branch.revision_tree(rev_id),
                                 not no_backup)
 
 
@@ -1614,8 +1626,8 @@
         if verbose and quiet:
             raise BzrCommandError('Cannot pass both quiet and verbose')
 
-        b = Branch.open_containing('.')[0]
-        parent = b.get_parent()
+        tree = WorkingTree.open_containing('.')[0]
+        parent = tree.branch.get_parent()
         if remote is None:
             if parent is None:
                 raise BzrCommandError("No missing location known or specified.")
@@ -1626,9 +1638,9 @@
         elif parent is None:
             # We only update parent if it did not exist, missing
             # should not change the parent
-            b.set_parent(remote)
+            tree.branch.set_parent(remote)
         br_remote = Branch.open_containing(remote)[0]
-        return show_missing(b, br_remote, verbose=verbose, quiet=quiet)
+        return show_missing(tree.branch, br_remote, verbose=verbose, quiet=quiet)
 
 
 class cmd_plugins(Command):
@@ -1658,7 +1670,7 @@
     @display_command
     def run(self, branch='.', revision=None, long=False):
         from bzrlib.testament import Testament
-        b = Branch.open_containing(branch)[0]
+        b = WorkingTree.open_containing(branch)[0].branch
         b.lock_read()
         try:
             if revision is None:
@@ -1696,16 +1708,16 @@
     @display_command
     def run(self, filename, all=False, long=False):
         from bzrlib.annotate import annotate_file
-        b, relpath = Branch.open_containing(filename)
-        b.lock_read()
+        tree, relpath = WorkingTree.open_containing(filename)
+        branch = tree.branch
+        branch.lock_read()
         try:
-            tree = WorkingTree(b.base, b)
-            tree = b.revision_tree(b.last_revision())
             file_id = tree.inventory.path2id(relpath)
+            tree = branch.revision_tree(branch.last_revision())
             file_version = tree.inventory[file_id].revision
-            annotate_file(b, file_version, file_id, long, all, sys.stdout)
+            annotate_file(branch, file_version, file_id, long, all, sys.stdout)
         finally:
-            b.unlock()
+            branch.unlock()
 
 
 class cmd_re_sign(Command):
@@ -1723,7 +1735,7 @@
             raise BzrCommandError('You can only supply one of revision_id or --revision')
         if revision_id is None and revision is None:
             raise BzrCommandError('You must supply either --revision or a revision_id')
-        b = Branch.open_containing('.')[0]
+        b = WorkingTree.open_containing('.')[0].branch
         gpg_strategy = gpg.GPGStrategy(config.BranchConfig(b))
         if revision_id is not None:
             b.sign_revision(revision_id, gpg_strategy)

=== modified file 'bzrlib/selftest/blackbox.py'
--- bzrlib/selftest/blackbox.py	2005-11-13 19:44:06 +0000
+++ bzrlib/selftest/blackbox.py	2005-11-17 08:12:13 +0000
@@ -1158,7 +1158,3 @@
         url = self.get_remote_url('branch/file')
         output = self.capture('log %s' % url)
         self.assertEqual(7, len(output.split('\n')))
-        
-
-
-

